#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

/* For SystemCoreClock */
#include "chip.h"

/*-----------------------------------------------------------
* Application specific definitions.
*
* These definitions should be adjusted for your particular hardware and
* application requirements.
*
* THESE PARAMETERS ARE DESCRIBED WITHIN THE 'CONFIGURATION' SECTION OF THE
* FreeRTOS API DOCUMENTATION AVAILABLE ON THE FreeRTOS.org WEB SITE.
*----------------------------------------------------------*/

#define configCHECK_FOR_STACK_OVERFLOW	0
#define configASSERT(K)     if( (K) == 0 ) { taskDISABLE_INTERRUPTS(); for( ;; ); }
#define configRECORD_STACK_HIGH_ADDRESS (1)
#define configUSE_TRACE_FACILITY	1
#define configINCLUDE_FREERTOS_TASK_C_ADDITIONS_H	1

// The following definitions must be made for FreeRTOS to work
#define configUSE_PREEMPTION        1
#define configUSE_IDLE_HOOK         0
#define configMAX_PRIORITIES        ( 8 )
#define configUSE_TICK_HOOK         0
#define configCPU_CLOCK_HZ          ( (uint32_t) SystemCoreClock )
#define configTICK_RATE_HZ          ( (TickType_t) 1000 )
#define configMINIMAL_STACK_SIZE    ( (uint16_t) 96 )
#define configUSE_16_BIT_TICKS      0

//#define configUSE_TRACE_FACILITY    1

#define configIDLE_SHOULD_YIELD                 1
#define configUSE_TIME_SLICING                  1
#define configUSE_TASK_NOTIFICATIONS            1
#define configENABLE_BACKWARD_COMPATIBILITY     0
#define configUSE_COUNTING_SEMAPHORES			0
#define configUSE_CO_ROUTINES       			0
#define configUSE_MUTEXES           			0
#define configUSE_TICKLESS_IDLE     			0

/* Memory allocation related definitions. */
#define configSUPPORT_STATIC_ALLOCATION         1
#define configSUPPORT_DYNAMIC_ALLOCATION        0
 //#define configTOTAL_HEAP_SIZE                   ( (size_t) ( 4 * 1024 ) )
//#define configAPPLICATION_ALLOCATED_HEAP        0

/* Software timer related definitions. */
#define configUSE_TIMERS                        0
#define configTIMER_TASK_PRIORITY               (tskIDLE_PRIORITY + 2UL)
#define configTIMER_QUEUE_LENGTH                4
#define configTIMER_TASK_STACK_DEPTH            configMINIMAL_STACK_SIZE



//#define configMAX_CO_ROUTINE_PRIORITIES ( 2 )

#define configUSE_COUNTING_SEMAPHORES   1
//#define configUSE_ALTERNATIVE_API       0
//#define configCHECK_FOR_STACK_OVERFLOW  0
//#define configUSE_RECURSIVE_MUTEXES     0
#define configQUEUE_REGISTRY_SIZE       5
//#define configGENERATE_RUN_TIME_STATS   0

/* Set the following definitions to 1 to include the API function, or zero
   to exclude the API function. */
#define INCLUDE_vTaskPrioritySet                0
#define INCLUDE_uxTaskPriorityGet               0
#define INCLUDE_vTaskDelete                     0
#define INCLUDE_vTaskSuspend                    1
#define INCLUDE_xResumeFromISR                  0
#define INCLUDE_vTaskDelayUntil                 1
#define INCLUDE_vTaskDelay                      1
#define INCLUDE_xTaskGetSchedulerState          0
#define INCLUDE_xTaskGetCurrentTaskHandle       0
#define INCLUDE_uxTaskGetStackHighWaterMark     0
#define INCLUDE_xTaskGetIdleTaskHandle          0
#define INCLUDE_eTaskGetState                   0
#define INCLUDE_xEventGroupSetBitFromISR        0
#define INCLUDE_xTimerPendFunctionCall          0
#define INCLUDE_xTaskAbortDelay                 0
#define INCLUDE_xTaskGetHandle                  0
#define INCLUDE_xTaskResumeFromISR              0


/* Use the system definition, if there is one */
#define configPRIO_BITS       3

/* The lowest interrupt priority that can be used in a call to a "set priority"
   function. */
#define configLIBRARY_LOWEST_INTERRUPT_PRIORITY         0x08

/* The highest interrupt priority that can be used by any interrupt service
   routine that makes calls to interrupt safe FreeRTOS API functions.  DO NOT CALL
   INTERRUPT SAFE FREERTOS API FUNCTIONS FROM ANY INTERRUPT THAT HAS A HIGHER
   PRIORITY THAN THIS! (higher priorities are lower numeric values. */
#define configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY    5

/* Interrupt priorities used by the kernel port layer itself.  These are generic
   to all Cortex-M ports, and do not rely on any particular library functions. */
#define configKERNEL_INTERRUPT_PRIORITY         ( configLIBRARY_LOWEST_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )
#define configMAX_SYSCALL_INTERRUPT_PRIORITY    ( configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY << (8 - configPRIO_BITS) )

/* Definitions that map the FreeRTOS port interrupt handlers to their CMSIS
   standard names - or at least those used in the unmodified vector table. */
#define vPortSVCHandler SVC_Handler
 #define xPortPendSVHandler PendSV_Handler
#define xPortSysTickHandler SysTick_Handler

#endif /* FREERTOS_CONFIG_H */
