/*
===============================================================================
 Name        : xxx.c
 Author      : $(author)
 Version     :
 Copyright   : $(copyright)
 Description : main definition
===============================================================================
*/

#include "FreeRTOS.h"
#include "chip.h"
#include "task.h"
#include "queue.h"

#define BLUE_PIN				17
#define GREEN_PIN				12
#define BLUE_PORT				0
#define GREEN_PORT				0
#define QUEUE_LENGTH_RX 		10
#define TASK_STACK_SIZE_MAIN	256

const uint32_t OscRateIn = 12000000;
const uint32_t RTCOscRateIn = 32768;

static StaticTask_t _task_main;
static StackType_t _task_stack_main[ TASK_STACK_SIZE_MAIN ];
static TaskHandle_t _task_hdl_main;
static void main_task( void * pvParameters );
StaticQueue_t _queue_hdr_rx;
static uint8_t _queue_buf_rx[ QUEUE_LENGTH_RX * sizeof( uint32_t ) ];
QueueHandle_t _queue_hdl_rx;

uint32_t frame;
uint32_t main_event;

#define DISABLE_WRITE_BUFFER
//******************************************************************************
int main(void)
//******************************************************************************
{
#ifdef DISABLE_WRITE_BUFFER
	SCnSCB->ACTLR |= SCnSCB_ACTLR_DISDEFWBUF_Msk;
#endif

	SystemCoreClockUpdate();

	Chip_GPIO_Init(LPC_GPIO);
	Chip_GPIO_SetPinDIROutput(LPC_GPIO, GREEN_PORT, GREEN_PIN);
	Chip_GPIO_SetPinDIROutput(LPC_GPIO, BLUE_PORT, BLUE_PIN);

	Chip_Clock_EnablePeriphClock(SYSCTL_CLOCK_RIT);
	Chip_RIT_Init(LPC_RITIMER);
	Chip_RIT_SetTimerIntervalHz(LPC_RITIMER, 6);
	NVIC_SetPriority(RITIMER_IRQn, configLIBRARY_MAX_SYSCALL_INTERRUPT_PRIORITY);
	Chip_RIT_Enable(LPC_RITIMER);
	NVIC_EnableIRQ(RITIMER_IRQn);

	_queue_hdl_rx = xQueueCreateStatic( QUEUE_LENGTH_RX,
	                             sizeof( uint32_t ),
                                 _queue_buf_rx,
                                 &_queue_hdr_rx );
 	vQueueAddToRegistry(_queue_hdl_rx, "rx");

	_task_hdl_main = xTaskCreateStatic(
						main_task ,
						"main_task",
						TASK_STACK_SIZE_MAIN,
						NULL,
						(tskIDLE_PRIORITY + 1UL),
						_task_stack_main,
						&_task_main);

	vTaskStartScheduler();
//    while(1) {
//    	__WFI();
//    }
    return 0 ;
}

//******************************************************************************
static void main_task( void* ctx )
//******************************************************************************
{
	while(1){
		xQueueReceive( _queue_hdl_rx , &main_event , portMAX_DELAY );

		Chip_GPIO_SetPinToggle(LPC_GPIO, GREEN_PORT, GREEN_PIN);
	}
}

//******************************************************************************
void RIT_IRQHandler(void)
//******************************************************************************
{
	Chip_RIT_ClearIntStatus(LPC_RITIMER);

	xQueueSendFromISR( _queue_hdl_rx, &frame, NULL );
//	Chip_GPIO_SetPinToggle(LPC_GPIO, GREEN_PORT, GREEN_PIN);
}
